@@ -30,10 +30,10 @@ class LoguruStyleFormatter(logging.Formatter):
 
 def configure_logging():
     logger = logging.getLogger("shadowstep")
-    logger.setLevel(logging.DEBUG)
+    logger.setLevel(logging.INFO)
 
     handler = logging.StreamHandler(sys.stdout)
-    handler.setLevel(logging.DEBUG)
+    handler.setLevel(logging.INFO)
     handler.setFormatter(LoguruStyleFormatter(datefmt="%Y-%m-%d %H:%M:%S"))
 
     if not logger.handlers:
@@ -42,5 +42,6 @@ def configure_logging():
     # Применяем и к root
     logging.getLogger().handlers = logger.handlers
     logging.getLogger().setLevel(logger.level)
+    logger.propagate = False
 
 configure_logging()
